@@ -1,4 +1,3 @@
-
 from mezzanine.utils.cache import (cache_key_prefix, cache_installed,
                                    cache_get, cache_set)
 
@@ -23,7 +22,7 @@ class TemplateSettings(dict):
 
     def __getattr__(self, name):
         try:
-            self.__getitem__(name)
+            return self.__getitem__(name)
         except KeyError:
             raise AttributeError
 
@@ -32,12 +31,12 @@ def settings(request):
     """
     Add the settings object to the template context.
     """
+    from mezzanine.conf import settings
     settings_dict = None
     if cache_installed():
         cache_key = cache_key_prefix(request) + "context-settings"
         settings_dict = cache_get(cache_key)
     if not settings_dict:
-        from mezzanine.conf import settings
         settings.use_editable()
         settings_dict = TemplateSettings()
         for k in settings.TEMPLATE_ACCESSIBLE_SETTINGS:
@@ -46,4 +45,13 @@ def settings(request):
             settings_dict[k] = getattr(settings, k, DEPRECATED)
         if cache_installed():
             cache_set(cache_key, settings_dict)
+    # This is basically the same as the old ADMIN_MEDIA_PREFIX setting,
+    # we just use it in a few spots in the admin to optionally load a
+    # file from either grappelli or Django admin if grappelli isn't
+    # installed. We don't call it ADMIN_MEDIA_PREFIX in order to avoid
+    # any confusion.
+    if settings.GRAPPELLI_INSTALLED:
+        settings_dict["MEZZANINE_ADMIN_PREFIX"] = "grappelli/"
+    else:
+        settings_dict["MEZZANINE_ADMIN_PREFIX"] = "admin/"
     return {"settings": settings_dict}
