@@ -76,8 +76,7 @@ WIDGETS = {
 }
 
 # Some helper groupings of field types.
-CHOICES = (CHECKBOX, CHECKBOX_MULTIPLE, SELECT,
-           SELECT_MULTIPLE, RADIO_MULTIPLE)
+CHOICES = (CHECKBOX, SELECT, RADIO_MULTIPLE)
 DATES = (DATE, DATE_TIME, DOB)
 MULTIPLE = (CHECKBOX_MULTIPLE, SELECT_MULTIPLE)
 
