@@ -28,5 +28,6 @@ class ThreadedCommentAdmin(CommentsAdmin):
         return actions
 
 
-if not settings.COMMENTS_DISQUS_SHORTNAME:
+generic_comments = getattr(settings, "COMMENTS_APP", "") == "mezzanine.generic"
+if generic_comments and not settings.COMMENTS_DISQUS_SHORTNAME:
     admin.site.register(ThreadedComment, ThreadedCommentAdmin)
