@@ -78,7 +78,7 @@ def page(request, slug, template=u"pages/page.html", extra_context=None):
     if page.content_model is not None:
         templates.append(u"pages/%s/%s.html" % (template_name,
             page.content_model))
-    for parent in page.get_ascendants():
+    for parent in page.get_ascendants(for_user=request.user):
         parent_template_name = unicode(parent.slug)
         # Check for a template matching the page's content model.
         if page.content_model is not None:
